@@ -1,7 +1,9 @@
-use crate::prelude::{Axis, ControllerButton, Event, Key, KeyMod, Mouse, WindowEvent};
+use crate::prelude::*;
+use log::warn;
 use sdl2::{
     controller::{Axis as SdlAxis, Button as SdlButton},
     event::{Event as SdlEvent, WindowEvent as SdlWindowEvent},
+    joystick::HatState as SdlHatState,
     keyboard::{Keycode as SdlKeycode, Mod as SdlMod},
     mouse::MouseButton as SdlMouseButton,
 };
@@ -69,6 +71,16 @@ impl From<SdlEvent> for Event {
                 axis_idx,
                 value,
             },
+            SdlEvent::JoyHatMotion {
+                which,
+                hat_idx,
+                state,
+                ..
+            } => Self::JoyHatMotion {
+                joy_id: which,
+                hat_idx,
+                state: state.into(),
+            },
             SdlEvent::JoyBallMotion {
                 which,
                 ball_idx,
@@ -173,7 +185,22 @@ impl From<SdlEvent> for Event {
                 dy,
                 pressure,
             },
-            _ => Self::Unknown,
+            SdlEvent::AudioDeviceAdded {
+                which, iscapture, ..
+            } => Self::AudioDeviceAdded {
+                device_id: which,
+                iscapture,
+            },
+            SdlEvent::AudioDeviceRemoved {
+                which, iscapture, ..
+            } => Self::AudioDeviceRemoved {
+                device_id: which,
+                iscapture,
+            },
+            evt => {
+                warn!("Unsupported SDL `Event`: {:?}", evt);
+                Self::Unsupported
+            }
         }
     }
 }
@@ -196,7 +223,10 @@ impl From<SdlWindowEvent> for WindowEvent {
             SdlWindowEvent::FocusGained => Self::FocusGained,
             SdlWindowEvent::FocusLost => Self::FocusLost,
             SdlWindowEvent::Close => Self::Close,
-            _ => Self::Unknown,
+            evt => {
+                warn!("Unsupported SDL `WindowEvent`: {:?}", evt);
+                Self::Unsupported
+            }
         }
     }
 }
@@ -301,6 +331,24 @@ impl From<SdlKeycode> for Key {
             SdlKeycode::Down => Self::Down,
             SdlKeycode::Up => Self::Up,
             SdlKeycode::NumLockClear => Self::NumLock,
+            SdlKeycode::KpDivide => Self::KpDivide,
+            SdlKeycode::KpMultiply => Self::KpMultiply,
+            SdlKeycode::KpMinus => Self::KpMinus,
+            SdlKeycode::KpPlus => Self::KpPlus,
+            SdlKeycode::KpEnter => Self::KpEnter,
+            SdlKeycode::Kp1 => Self::Kp1,
+            SdlKeycode::Kp2 => Self::Kp2,
+            SdlKeycode::Kp3 => Self::Kp3,
+            SdlKeycode::Kp4 => Self::Kp4,
+            SdlKeycode::Kp5 => Self::Kp5,
+            SdlKeycode::Kp6 => Self::Kp6,
+            SdlKeycode::Kp7 => Self::Kp7,
+            SdlKeycode::Kp8 => Self::Kp8,
+            SdlKeycode::Kp9 => Self::Kp9,
+            SdlKeycode::Kp0 => Self::Kp0,
+            SdlKeycode::KpPeriod => Self::KpPeriod,
+            SdlKeycode::KpEquals => Self::KpEquals,
+            SdlKeycode::KpComma => Self::KpComma,
             SdlKeycode::LCtrl => Self::LCtrl,
             SdlKeycode::LShift => Self::LShift,
             SdlKeycode::LAlt => Self::LAlt,
@@ -309,7 +357,10 @@ impl From<SdlKeycode> for Key {
             SdlKeycode::RShift => Self::RShift,
             SdlKeycode::RAlt => Self::RAlt,
             SdlKeycode::RGui => Self::RGui,
-            _ => Self::Unknown,
+            keycode => {
+                warn!("Unsupported SDL `Keycode`: {:?}", keycode);
+                Self::Unsupported
+            }
         }
     }
 }
@@ -341,7 +392,10 @@ impl From<SdlMouseButton> for Mouse {
             SdlMouseButton::Left => Self::Left,
             SdlMouseButton::Middle => Self::Middle,
             SdlMouseButton::Right => Self::Right,
-            _ => Self::Unknown,
+            btn => {
+                warn!("Unsupported SDL `MouseButton`: {:?}", btn);
+                Self::Unsupported
+            }
         }
     }
 }
@@ -388,3 +442,20 @@ impl From<SdlAxis> for Axis {
         }
     }
 }
+
+impl From<SdlHatState> for HatState {
+    #[doc(hidden)]
+    fn from(hat: SdlHatState) -> Self {
+        match hat {
+            SdlHatState::LeftUp => Self::LeftUp,
+            SdlHatState::Left => Self::Left,
+            SdlHatState::LeftDown => Self::LeftDown,
+            SdlHatState::Up => Self::Up,
+            SdlHatState::Centered => Self::Centered,
+            SdlHatState::Down => Self::Down,
+            SdlHatState::RightUp => Self::RightUp,
+            SdlHatState::Right => Self::Right,
+            SdlHatState::RightDown => Self::RightDown,
+        }
+    }
+}
